@@ -79,8 +79,10 @@ sub init_via_xmlref {
 
     $self->media($ref->{Binding});
 
-    $self->NumMedia($ref->{NumberOfItems});
-    $self->nummedia($ref->{NumberOfItems});
+    # $self->NumMedia($ref->{NumberOfItems});
+    # $self->nummedia($ref->{NumberOfItems});
+    $self->NumMedia($ref->{NumberOfDiscs});
+    $self->nummedia($ref->{NumberOfDiscs});
 
     if ( defined $ref->{TheatricalReleaseDate} ) {
         my $year =  (split(/\-/, $ref->{TheatricalReleaseDate}))[0];
@@ -153,6 +155,9 @@ Returns the DVD's number of media (number of discs) as a string.
 
 Returns the DVD's theatrical release date.
 
+As of Net::Amazon 0.61 this method has been deprecated.  It appears that 
+this information is no longer from Amazon.
+
 =item mpaa_rating()
 
 Returns the DVD's MPAA rating.
